==> zio-aws-groundstation_2.12-5.20.37.1-sources.jar: zio/aws/groundstation/model/ListDataflowEndpointGroupsResponse.scala <==
package zio.aws.groundstation.model
import zio.aws.groundstation.model.primitives.PaginationToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListDataflowEndpointGroupsResponse(
    dataflowEndpointGroupList: Optional[
      Iterable[zio.aws.groundstation.model.DataflowEndpointListItem]
    ] = Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.ListDataflowEndpointGroupsResponse = {
    import ListDataflowEndpointGroupsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.ListDataflowEndpointGroupsResponse
      .builder()
      .optionallyWith(
        dataflowEndpointGroupList.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.dataflowEndpointGroupList)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.groundstation.model.ListDataflowEndpointGroupsResponse.ReadOnly =
    zio.aws.groundstation.model.ListDataflowEndpointGroupsResponse
      .wrap(buildAwsValue())
}
object ListDataflowEndpointGroupsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.ListDataflowEndpointGroupsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.groundstation.model.ListDataflowEndpointGroupsResponse =
      zio.aws.groundstation.model.ListDataflowEndpointGroupsResponse(
        dataflowEndpointGroupList.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def dataflowEndpointGroupList: Optional[
      List[zio.aws.groundstation.model.DataflowEndpointListItem.ReadOnly]
    ]
    def nextToken: Optional[PaginationToken]
    def getDataflowEndpointGroupList: ZIO[Any, AwsError, List[
      zio.aws.groundstation.model.DataflowEndpointListItem.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "dataflowEndpointGroupList",
      dataflowEndpointGroupList
    )
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.ListDataflowEndpointGroupsResponse
  ) extends zio.aws.groundstation.model.ListDataflowEndpointGroupsResponse.ReadOnly {
    override val dataflowEndpointGroupList: Optional[
      List[zio.aws.groundstation.model.DataflowEndpointListItem.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.dataflowEndpointGroupList())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.groundstation.model.DataflowEndpointListItem.wrap(item)
        }.toList
      )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value =>
        zio.aws.groundstation.model.primitives.PaginationToken(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.ListDataflowEndpointGroupsResponse
  ): zio.aws.groundstation.model.ListDataflowEndpointGroupsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-groundstation_3-5.17.130.7-sources.jar: zio/aws/groundstation/model/ListDataflowEndpointGroupsResponse.scala <==
package zio.aws.groundstation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListDataflowEndpointGroupsResponse(
    dataflowEndpointGroupList: Option[
      Iterable[zio.aws.groundstation.model.DataflowEndpointListItem]
    ] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.ListDataflowEndpointGroupsResponse = {
    import ListDataflowEndpointGroupsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.ListDataflowEndpointGroupsResponse
      .builder()
      .optionallyWith(
        dataflowEndpointGroupList.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.dataflowEndpointGroupList)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.groundstation.model.ListDataflowEndpointGroupsResponse.ReadOnly =
    zio.aws.groundstation.model.ListDataflowEndpointGroupsResponse
      .wrap(buildAwsValue())
}
object ListDataflowEndpointGroupsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.ListDataflowEndpointGroupsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.groundstation.model.ListDataflowEndpointGroupsResponse =
      zio.aws.groundstation.model.ListDataflowEndpointGroupsResponse(
        dataflowEndpointGroupList.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def dataflowEndpointGroupList: Option[
      List[zio.aws.groundstation.model.DataflowEndpointListItem.ReadOnly]
    ]
    def nextToken: Option[String]
    def getDataflowEndpointGroupList: ZIO[Any, AwsError, List[
      zio.aws.groundstation.model.DataflowEndpointListItem.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "dataflowEndpointGroupList",
      dataflowEndpointGroupList
    )
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.ListDataflowEndpointGroupsResponse
  ) extends zio.aws.groundstation.model.ListDataflowEndpointGroupsResponse.ReadOnly {
    override val dataflowEndpointGroupList: Option[
      List[zio.aws.groundstation.model.DataflowEndpointListItem.ReadOnly]
    ] = scala
      .Option(impl.dataflowEndpointGroupList())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.groundstation.model.DataflowEndpointListItem.wrap(item)
        }.toList
      )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.ListDataflowEndpointGroupsResponse
  ): zio.aws.groundstation.model.ListDataflowEndpointGroupsResponse.ReadOnly =
    new Wrapper(impl)
}
